package com.emato.cus.supervise.biz.acqGoodsMoveSchedule.up;

import com.emato.cus.supervise.biz.WmsData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqGoodsMove;
import com.emato.cus.supervise.domainOmsShop.OmsShopAcqGoodsMove;
import com.emato.cus.supervise.service.omsshop.OmsShopAcqGoodsMoveService;
import com.emato.cus.supervise.service.wms.WmsAcqGoodsMoveService;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 * 门店转移 Oms 门店
 * @author Scott Chen
 * @version 1.0
 * 2020-03-30 11:27
 */
@Component
public class AcqGoodsMoveUpOmsShopData {
    private static final Logger logger = LoggerFactory.getLogger(AcqGoodsMoveUpOmsShopData.class);

    @Autowired
    private OmsShopAcqGoodsMoveService omsShopAcqGoodsMoveService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.OMS_SHOP_ACQ_GOODS_MOVE.getCode() + "]" + EmtRecordTimeEnum.OMS_SHOP_ACQ_GOODS_MOVE.getName();


    public List getOmsShopData(String thisTime) {
        logger.info("---------- 门店转移::获取本次监控数据开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            String err = "---【" + DATA_TYPE_INFO + "】本次扫描时间为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        ImmutableMap param = ImmutableMap.of("thisTime", thisTime);
        List<OmsShopAcqGoodsMove> resultList = omsShopAcqGoodsMoveService.getOmsShopAcqGoodsMove(param);

        if (resultList == null || resultList.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】获取本次监控数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }
        logger.info("---【" + DATA_TYPE_INFO + "】获取本次监控数据{}条.", resultList.size());

        logger.info("---------- 门店转移::获取本次监控数据结束 --------------------");

        return resultList;
    }
}
