package com.emato.cus.supervise.biz.acqShelfLoad.down;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.biz.EmsClassConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domain.WmsAcqShelfLoad;
import com.emato.cus.supervise.domainCus.CusAcqShelfLoad04;
import com.emato.cus.supervise.domainOms.OmsMerchInfo;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 门店货物上下架数据 门店出场 即下架
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 13:40
 */
@Component
public class AcqShelfLoadDownDataConversion implements DataConversion {


    private final static Logger logger = LoggerFactory.getLogger(AcqShelfLoadDownDataConversion.class);

    /**
     * 门店货物上下架数据 门店出场 即下架
     * 外部数据转换
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("企业货物上下架:下架:开始转换oms，wms 组装cus数据===========================");

        List<WmsAcqShelfLoad> wmsList = (List<WmsAcqShelfLoad>) params.get("wmsList");

        List<OmsMerchInfo> omsList = (List<OmsMerchInfo>) params.get("omsList");
        final Map<String, OmsMerchInfo> omsMerchInfoMap = omsList.stream().collect(Collectors.toMap(k -> k.getMerchSn() + "_" + k.getEmsClassType(), v -> v));

        List<OmsProductInfo> productInfoList = (List<OmsProductInfo>) params.get("productInfoList");
        final Map<String,OmsProductInfo> omsProductInfoMap =  new HashMap<>();
        //final Map<String,OmsProductInfo> omsProductInfoMap = productInfoList.stream().collect(Collectors.toMap(k->k.getSkuNo(), v->v));
        for (int i = 0, len = productInfoList.size(); i < len; i++) {
            if (omsProductInfoMap.containsKey(productInfoList.get(i).getSkuNo())) {
                continue;
            } else {
                omsProductInfoMap.put(productInfoList.get(i).getSkuNo(), productInfoList.get(i));
            }
        }

        
        List<CusAcqShelfLoad04> cusAcqShelfLoad04List = Lists.newArrayList();

        for (int i = 0; i < wmsList.size(); i++) {
            // #20190521001
            // 未作try catch 导致一个sku数据异常，全部终止
            try {
                WmsAcqShelfLoad wmsAcqShelfLoad = wmsList.get(i);
                if (wmsAcqShelfLoad.getSeatNo() == null) {
                    logger.debug("sku：{}, 下架库位为空", wmsAcqShelfLoad.getSkuNo());
                    continue;
                }

                // 库位向账册分类转换
                String emsClassType = EmsClassConversion.convertBySeatNo(wmsAcqShelfLoad.getSeatNo());
                // 拼接商户账册分类
                String merchEmsType = wmsAcqShelfLoad.getMerchSn() + "_" + emsClassType;
                if (!omsMerchInfoMap.containsKey(merchEmsType)) {
                    logger.error("当前转换的商户账册分类为: {}, WMS传回的商户在OMS中无此账册分类", merchEmsType);
                    continue;
                }
                OmsMerchInfo omsMerchInfo = omsMerchInfoMap.get(merchEmsType);


                OmsProductInfo omsProductInfo = omsProductInfoMap.get(wmsAcqShelfLoad.getSkuNo());
                String osku = omsProductInfo.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}, 对应的产品备案数据异常", osku);
                    continue;
                }
                //logger.debug("当前转换的sku为: {}", omsProductInfo.getSkuNo());

                CusAcqShelfLoad04 cusAcqShelfLoad04 = new CusAcqShelfLoad04();
                cusAcqShelfLoad04.setId(wmsAcqShelfLoad.getId());
                cusAcqShelfLoad04.setGoodsName(wmsAcqShelfLoad.getGoodsName());

                cusAcqShelfLoad04.setCodeTs(omsProductInfo.getCodeTs());

                cusAcqShelfLoad04.setFormNoDec(wmsAcqShelfLoad.getFormNoDec());
                cusAcqShelfLoad04.setFormNo(wmsAcqShelfLoad.getFormNo());
                cusAcqShelfLoad04.setSkuNo(wmsAcqShelfLoad.getSkuNo());
                cusAcqShelfLoad04.setGoodsId(wmsAcqShelfLoad.getGoodsId());
                cusAcqShelfLoad04.setgUnit(wmsAcqShelfLoad.getgUnit());
                cusAcqShelfLoad04.setgQty(wmsAcqShelfLoad.getgQty());

                cusAcqShelfLoad04.setLegalQty(omsProductInfo.getLegalQty());
                cusAcqShelfLoad04.setLegalUnit(omsProductInfo.getLegalUnit());
                cusAcqShelfLoad04.setGoodsModel(omsProductInfo.getGoodsModel());

                cusAcqShelfLoad04.setGoodsModel(wmsAcqShelfLoad.getGoodsModel());

                cusAcqShelfLoad04.setLocalEmsNo(omsMerchInfo.getCusEmsNo());
                cusAcqShelfLoad04.setSeatNo(wmsAcqShelfLoad.getSeatNo());
                cusAcqShelfLoad04.setShelfLoadTime(wmsAcqShelfLoad.getShelfLoadTime());
                cusAcqShelfLoad04.setShelfLoadType(wmsAcqShelfLoad.getShelfLoadType());
                cusAcqShelfLoad04.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqShelfLoad04.setStoreUscCode(Dict.storeUscCode);
                cusAcqShelfLoad04.setStoreCustomsCode(Dict.storeCustomsCode);
                if (Dict.storeCodeMap.containsKey(wmsAcqShelfLoad.getStoreCode())) {
                    cusAcqShelfLoad04.setStoreCode(Dict.storeCodeMap.get(wmsAcqShelfLoad.getStoreCode()));
                } else {
                    cusAcqShelfLoad04.setStoreCode(Dict.storeCodeMap.get("Others"));
                }
                cusAcqShelfLoad04.setCreateTime(LocalDateTime.now());
                cusAcqShelfLoad04.setCreaterSn(Dict.operater);
                cusAcqShelfLoad04.setModerSn(Dict.operater);
                cusAcqShelfLoad04.setModTime(LocalDateTime.now());

                cusAcqShelfLoad04List.add(cusAcqShelfLoad04);
            }catch (Exception e){
                logger.error("企业货物上下架:下架:信息组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("企业货物上下架:下架:转换oms，wms 组装cus数据结束===========================");
        return cusAcqShelfLoad04List;
    }
}
