package com.emato.cus.supervise.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

/**
 * Spring Context
 *
 * @author Scott Chen
 * @date 2017/2/27
 *
 */
@Component
public class SpringApplicationContextSupport implements ApplicationContextAware, DisposableBean {
	private static final Logger logger = LoggerFactory.getLogger(SpringApplicationContextSupport.class);

    /**
     * Spring应用上下文
     */
	private static ApplicationContext applicationContext = null;


	/**
	 * 注入 {@Code ApplicationContext} 进来
	 * {@link org.springframework.context.ApplicationContext}
	 *
	 * @param applicationContext
	 * @throws BeansException
	 */
	@Override
	public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
		logger.info("注入 Inject ApplicationContext in SpringApplicationContextSupport");
		SpringApplicationContextSupport.applicationContext = applicationContext;
	}

	@Override
	public void destroy() throws Exception {
		applicationContext = null;
	}


	public static ApplicationContext getApplicationContext() {
		return applicationContext;
	}

	@SuppressWarnings("unchecked")
	public static <T> T getBean(String name) {
		return (T) applicationContext.getBean(name);
	}

	@SuppressWarnings("unchecked")
	public static <T> T getBean(Class<T> requiredType) {
		return applicationContext.getBean(requiredType);
	}

	@SuppressWarnings("unchecked")
	public static <T> T getBean(String name, Class<T> requiredType) {
		return applicationContext.getBean(name, requiredType);
	}

	@SuppressWarnings("unchecked")
	public static <T> T getBean(String name, Object... args) {
		return (T) applicationContext.getBean(name, args);
	}

}
